pitchtools.NamedChromaticPitchVector
====================================

.. inheritance-diagram:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.chromatic_pitch_numbers

.. autoattribute:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.named_chromatic_pitches

.. autoattribute:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.clear

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.copy

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.get

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.has_key

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.items

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.iteritems

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.iterkeys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.itervalues

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.keys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.pop

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.popitem

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.setdefault

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.update

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.values

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.viewitems

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.viewkeys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.viewvalues

    Inherited from :py:class:`__builtin__.dict`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__cmp__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__contains__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__delitem__

    Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__eq__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__ge__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__getitem__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__gt__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__iter__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__le__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__len__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__lt__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__ne__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__repr__

.. automethod:: abjad.tools.pitchtools.NamedChromaticPitchVector.NamedChromaticPitchVector.NamedChromaticPitchVector.__setitem__

    Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`
